"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
class TarUnpacker {
    constructor(debug) {
        this.debug = debug;
    }
    unpackEntry(header, bodyStream, rootDir, next) {
        const entryPath = path.join(rootDir, header.name);
        if (header.type === 'directory') {
            this.extractDirectoryEntry(entryPath, next);
        }
        else if (header.type === 'file') {
            this.extractFileEntry(entryPath, bodyStream, next);
        }
        else if (header.type === 'symlink') {
            this.extractSymlinkEntry(next);
        }
        else {
            throw new Error(`UNKNOWN HEADER TYPE: ${header.type}`);
        }
    }
    extractDirectoryEntry(dirPath, next) {
        if (this.debug) {
            console.log('creating directory:', dirPath);
        }
        if (!fs.existsSync(dirPath)) {
            fs.mkdirSync(dirPath);
        }
        next();
    }
    extractFileEntry(filePath, bodyStream, next) {
        if (this.debug) {
            console.log('creating file:', filePath);
        }
        const fileStream = fs.createWriteStream(filePath);
        bodyStream.on('end', next);
        bodyStream.pipe(fileStream);
    }
    extractSymlinkEntry(next) {
        next();
    }
}
exports.default = TarUnpacker;
